@@ -44,7 +44,7 @@ private Q_SLOTS:
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         auto job = new KIMAP::ListJob(&session);
-        job->setIncludeUnsubscribed(true);
+        job->setOption(KIMAP::ListJob::IncludeUnsubscribed);
         QVERIFY(job->exec());
 
         fakeServer.quit();
