@@ -10,20 +10,25 @@
 
 #include "acljobbase_p.h"
 #include "response_p.h"
-#include "session_p.h"
 #include "rfccodecs.h"
+#include "session_p.h"
 
 namespace KIMAP
 {
 class ListRightsJobPrivate : public AclJobBasePrivate
 {
 public:
-    ListRightsJobPrivate(Session *session, const QString &name) : AclJobBasePrivate(session, name), defaultRights(Acl::None) {}
-    ~ListRightsJobPrivate() { }
+    ListRightsJobPrivate(Session *session, const QString &name)
+        : AclJobBasePrivate(session, name)
+        , defaultRights(Acl::None)
+    {
+    }
+    ~ListRightsJobPrivate()
+    {
+    }
 
     QList<Acl::Rights> possibleRights;
     Acl::Rights defaultRights;
-
 };
 }
 
@@ -32,7 +37,6 @@ using namespace KIMAP;
 ListRightsJob::ListRightsJob(Session *session)
     : AclJobBase(*new ListRightsJobPrivate(session, i18n("ListRights")))
 {
-
 }
 
 ListRightsJob::~ListRightsJob()
@@ -51,8 +55,7 @@ void ListRightsJob::handleResponse(const Response &response)
     Q_D(ListRightsJob);
 
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() >= 4 &&
-                response.content[1].toString() == "LISTRIGHTS") {
+        if (response.content.size() >= 4 && response.content[1].toString() == "LISTRIGHTS") {
             QByteArray s = response.content[4].toString();
             d->defaultRights = Acl::rightsFromString(s);
             int i = 5;
