@@ -6,8 +6,8 @@
 
 #include "setquotajob.h"
 
-#include <KLocalizedString>
 #include "kimap_debug.h"
+#include <KLocalizedString>
 
 #include "quotajobbase_p.h"
 #include "response_p.h"
@@ -18,8 +18,13 @@ namespace KIMAP
 class SetQuotaJobPrivate : public QuotaJobBasePrivate
 {
 public:
-    SetQuotaJobPrivate(Session *session, const QString &name) : QuotaJobBasePrivate(session, name) { }
-    ~SetQuotaJobPrivate() { }
+    SetQuotaJobPrivate(Session *session, const QString &name)
+        : QuotaJobBasePrivate(session, name)
+    {
+    }
+    ~SetQuotaJobPrivate()
+    {
+    }
 
     QMap<QByteArray, qint64> setList;
     QByteArray root;
@@ -52,7 +57,7 @@ void SetQuotaJob::doStart()
     }
 
     qCDebug(KIMAP_LOG) << "SETQUOTA " << '\"' + d->root + "\" " + s;
-    //XXX: [alexmerry, 2010-07-24]: should d->root be quoted properly?
+    // XXX: [alexmerry, 2010-07-24]: should d->root be quoted properly?
     d->tags << d->sessionInternal()->sendCommand("SETQUOTA", '\"' + d->root + "\" " + s);
 }
 
@@ -60,8 +65,7 @@ void SetQuotaJob::handleResponse(const Response &response)
 {
     Q_D(SetQuotaJob);
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() >= 4 &&
-                response.content[1].toString() == "QUOTA") {
+        if (response.content.size() >= 4 && response.content[1].toString() == "QUOTA") {
             d->quota = d->readQuota(response.content[3]);
         }
     }
